@@ -17,9 +17,15 @@
 /* Default runtime library to use. */
 #define CLANG_DEFAULT_RTLIB ""
 
+/* Default objcopy to use */
+#define CLANG_DEFAULT_OBJCOPY "objcopy"
+
 /* Default OpenMP runtime used by -fopenmp. */
 #define CLANG_DEFAULT_OPENMP_RUNTIME "libomp"
 
+/* Default architecture for OpenMP offloading to Nvidia GPUs. */
+#define CLANG_OPENMP_NVPTX_DEFAULT_ARCH "sm_35"
+
 /* Multilib suffix for libdir. */
 #define CLANG_LIBDIR_SUFFIX ""
 
@@ -29,6 +35,10 @@
 /* Directories clang will search for headers */
 #define C_INCLUDE_DIRS ""
 
+/* Directories clang will search for configuration files */
+/* #undef CLANG_CONFIG_FILE_SYSTEM_DIR */
+/* #undef CLANG_CONFIG_FILE_USER_DIR */
+
 /* Default <path> to all compiler invocations for --sysroot=<path>. */
 #define DEFAULT_SYSROOT ""
 
@@ -38,11 +48,14 @@
 /* Define if we have libxml2 */
 #define CLANG_HAVE_LIBXML 1
 
+/* Define if we have z3 and want to build it */
+/* #undef CLANG_ANALYZER_WITH_Z3 */
+
 /* Define if we have sys/resource.h (rlimits) */
 /* #undef CLANG_HAVE_RLIMITS */
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 4.0.0"
+#define BACKEND_PACKAGE_STRING "LLVM 6.0.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
@@ -53,4 +66,9 @@
 /* enable x86 relax relocations by default */
 #define ENABLE_X86_RELAX_RELOCATIONS 0
 
+/* Enable each functionality of modules */
+#define CLANG_ENABLE_ARCMT 1
+#define CLANG_ENABLE_OBJC_REWRITER 1
+#define CLANG_ENABLE_STATIC_ANALYZER 1
+
 #endif
